#' PlotMissingnessSummary
#'
#' Create plot with overview of missing data.
#'
#' @param inputData Pre-processed input data. Required.
#' @param columnNames Names of columns in \code{inputData} selected for missingness plot. Optional.
#'   Default = \code{c("Transmission", "Migr", "Gender", "Age", "FirstCD4Count")}
#' @param labels Labels to be displayed instead of strings in \code{columnNames}. Optional.
#'   Default = \code{c("Transm.", "Migrant", "Gender", "Age", "CD4")}
#'
#' @return plot object
#'
#' @examples
#' \dontrun{
#' PlotMissingnessSummary(inputData)
#' }
#'
#' @export
PlotMissingnessSummary <- function(
  inputData,
  columnNames = c("Transmission", "Migr", "Gender", "Age", "FirstCD4Count"),
  labels = c("Transm.", "Migrant", "Gender", "Age", "CD4"))
{
  stopifnot(!missing(inputData))

  columnNames <- columnNames[columnNames %in% colnames(inputData)]

  if (length(columnNames) > 0) {
    missSummary <- GetMissingnessSummary(inputData[, ..columnNames])

    missPlot <- PlotMissingness(missSummary,
                                combined = FALSE,
                                numbers = TRUE,
                                prop = TRUE,
                                sortVars = TRUE,
                                varheight = FALSE,
                                digits = 2,
                                labels = labels,
                                cex.axis = .9,
                                gap = 1,
                                ylabs = c("Relative frequency of missing data",
                                          "Missing data patterns"))

  } else {
    missPlot <- NULL
  }

  invisible(missPlot)
}
