# Module globals
# NONE

# User interface
dataSummaryUI <- function(id)
{
  ns <- NS(id)

  tagList(
    div(style = "margin-top: 15px"),
    box(
      width = 12,
      title = "Input data summary",
      solidHeader = FALSE,
      status = "primary",
      collapsible = TRUE,
      withSpinner(
        tagList(
          h3("1. Missing data summary"),
          plotOutput(ns("missPlot")),
          h3("2. Observed delay density"),
          plotOutput(ns("delayDensityPlot")),
          h3("3. Observed delay by notification time"),
          plotOutput(ns("meanDelayPlot"))
        ),
        type = 7,
        proxy.height = "50px")
    )
  )
}

# Server logic
dataSummary <- function(input, output, session, inputData)
{
  # Get namespace
  ns <- session$ns

  artifacts <- reactive({
    GetDataSummaryArtifacts(inputData())
  })

  output[["missPlot"]] <- renderPlot({
    replayPlot(artifacts()$MissPlot)
  })

  output[["delayDensityPlot"]] <- renderPlot({
    replayPlot(artifacts()$DelayDensityPlot)
  })

  output[["meanDelayPlot"]] <- renderPlot({
    replayPlot(artifacts()$MeanDelayPlot)
  })
}
